# bestia
***
I've been writing code for web scraping command-line applications for some time now. Over the years I've found myself reaching out for the same functions over and over again, so I've put them together in this library. Enjoy!
